# History

## v1.4

Publishing procedure update.

## v1.3

- fix bugs with multiple args and click 8.0
  (if multiple is not set and default is [],
  a string '[]' is given as argument)

## v1.2

- updated clickable (v1.3)

## v1.1

* updated clickable (v1.1)
* some build enhancements (wip)


## v1.0 (2021-08-31)

* reworked versioning and build system
